import { UserType, VerificationStatus, OffsetStatus, TransactionStatus } from '@prisma/client';

// User Types
export interface CreateUserRequest {
  email: string;
  password: string;
  fullName: string;
  userType: UserType;
}

export interface LoginRequest {
  email: string;
  password: string;
}

export interface UserResponse {
  id: number;
  email: string;
  fullName: string;
  userType: UserType;
  isActive: boolean;
  createdAt: Date;
  walletAddress?: string;
}

export interface JwtPayload {
  userId: number;
  email: string;
  userType: UserType;
}

// Wallet Types
export interface WalletLinkRequest {
  walletAddress: string;
}

export interface WalletResponse {
  success: boolean;
  walletLinked: boolean;
  walletAddress?: string;
  balance?: number;
  message?: string;
}

// Carbon Project Types
export interface CreateProjectRequest {
  title: string;
  description: string;
  location: string;
  projectType: string;
  methodology: string;
  totalCreditsAvailable: number;
  pricePerCredit: number;
  startDate: Date;
  endDate: Date;
}

export interface UpdateProjectRequest {
  title?: string;
  description?: string;
  location?: string;
  projectType?: string;
  methodology?: string;
  totalCreditsAvailable?: number;
  pricePerCredit?: number;
  startDate?: Date;
  endDate?: Date;
  verificationDocumentUrl?: string;
}

export interface ProjectResponse {
  id: number;
  title: string;
  description: string;
  location: string;
  projectType: string;
  methodology: string;
  totalCreditsAvailable: number;
  creditsSold: number;
  pricePerCredit: number;
  startDate: Date;
  endDate: Date;
  verificationStatus: VerificationStatus;
  verificationDocumentUrl?: string;
  isActive: boolean;
  contractAddress?: string;
  tokenId?: string;
  createdAt: Date;
  updatedAt: Date;
  developerId: number;
}

export interface ProjectListResponse {
  projects: ProjectResponse[];
  total: number;
  page: number;
  pageSize: number;
}

// Transaction Types
export interface PurchaseRequest {
  projectId: number;
  quantity: number;
}

export interface TransactionResponse {
  id: number;
  transactionHash: string;
  quantity: number;
  pricePerCredit: number;
  totalAmount: number;
  status: TransactionStatus;
  blockNumber?: number;
  gasUsed?: number;
  createdAt: Date;
  confirmedAt?: Date;
  buyerId: number;
  offsetId: number;
}

export interface TransactionListResponse {
  transactions: TransactionResponse[];
  total: number;
  page: number;
  pageSize: number;
}

// Marketplace Types
export interface MarketplaceStats {
  totalProjects: number;
  verifiedProjects: number;
  totalCreditsAvailable: number;
  totalTransactions: number;
  totalVolumeTraded: number;
}

// Blockchain Types
export interface BlockchainTransaction {
  to: string;
  value: string;
  data: string;
  gasLimit: string;
  gasPrice: string;
}

export interface WalletInfo {
  address: string;
  privateKey: string;
  publicKey: string;
}

// API Response Types
export interface ApiResponse<T = any> {
  success: boolean;
  data?: T;
  message?: string;
  error?: string;
}

export interface PaginationOptions {
  page?: number;
  pageSize?: number;
}

export interface FilterOptions {
  projectType?: string;
  verificationStatus?: VerificationStatus;
  status?: TransactionStatus;
}

// Express Request Extensions
declare global {
  namespace Express {
    interface Request {
      user?: {
        id: number;
        email: string;
        userType: UserType;
      };
    }
  }
}

export { UserType, VerificationStatus, OffsetStatus, TransactionStatus };